@@ -1,4 +1,5 @@
 import json
+import json5  # type: ignore
 from pathlib import Path
 import sys
 from http import HTTPStatus
@@ -19,9 +20,11 @@ from .config import get_lab_config  # type: ignore
 from .utils import get_federated_extensions
 
 
+LOCALE = "en"
+
+
 def init_router(router, redirect_after_root):
     prefix_dir: Path = Path(sys.prefix)
-    LOCALE = "en"
 
     extensions_dir = prefix_dir / "share" / "jupyter" / "labextensions"
     federated_extensions, _ = get_federated_extensions(extensions_dir)
@@ -70,7 +73,7 @@ def init_router(router, redirect_after_root):
     @router.get(
         "/lab/api/listings/@jupyterlab/extensionmanager-extension/listings.json"
     )
-    async def get_listings():
+    async def get_listings(user=Depends(current_user)):
         return {
             "blocked_extensions_uris": [],
             "allowed_extensions_uris": [],
@@ -78,8 +81,15 @@ def init_router(router, redirect_after_root):
             "allowed_extensions": [],
         }
 
+    @router.get("/lab/api/translations/")
+    async def get_translations_(
+        lab_config=Depends(get_lab_config),
+        user: User = Depends(current_user),
+    ):
+        return RedirectResponse(f"{lab_config.base_url}lab/api/translations")
+
     @router.get("/lab/api/translations")
-    async def get_translations():
+    async def get_translations(user: User = Depends(current_user)):
         locale = Locale.parse("en")
         data = {
             "en": {
@@ -98,6 +108,7 @@ def init_router(router, redirect_after_root):
     @router.get("/lab/api/translations/{language}")
     async def get_translation(
         language,
+        user: User = Depends(current_user),
     ):
         global LOCALE
         if language == "en":
@@ -112,7 +123,7 @@ def init_router(router, redirect_after_root):
         package = ep.load()
         data = {}
         for path in (
-            Path(package.__file__).parent / "locale" / "fr_FR" / "LC_MESSAGES"
+            Path(package.__file__).parent / "locale" / language / "LC_MESSAGES"
         ).glob("*.json"):
             with open(path) as f:
                 data.update({path.stem: json.load(f)})
@@ -145,7 +156,7 @@ def init_router(router, redirect_after_root):
         ) as f:
             schema = json.load(f)
         key = f"{name1}:{name2}"
-        result = {
+        setting = {
             "id": f"@jupyterlab/{key}",
             "schema": schema,
             "version": package["version"],
@@ -155,10 +166,11 @@ def init_router(router, redirect_after_root):
             "created": None,
         }
         if user:
-            settings = json.loads(user.settings)
-            if key in settings:
-                result.update(settings[key])
-        return result
+            user_settings = json.loads(user.settings)
+            if key in user_settings:
+                setting.update(user_settings[key])
+                setting["settings"] = json5.loads(user_settings[key]["raw"])
+        return setting
 
     @router.put(
         "/lab/api/settings/@jupyterlab/{name0}:{name1}",
@@ -206,6 +218,7 @@ def init_router(router, redirect_after_root):
             }
             if key in user_settings:
                 setting.update(user_settings[key])
+                setting["settings"] = json5.loads(user_settings[key]["raw"])
             settings.append(setting)
         return {"settings": settings}
 
